<?php
/* ------------------------------------------------------------------------------------
*  COPYRIGHT AND TRADEMARK NOTICE
*  Copyright 2008-2015 Arnan de Gans. All Rights Reserved.
*  ADROTATE is a trademark of Arnan de Gans.

*  COPYRIGHT NOTICES AND ALL THE COMMENTS SHOULD REMAIN INTACT.
*  By using this code you agree to indemnify Arnan de Gans from any
*  liability that might arise from it's use.
------------------------------------------------------------------------------------ */

/*-------------------------------------------------------------
 Name:      AJdG Solutions API Library
 Version:	1.0 (for Analytics Spam Blocker)
---------------------------------------------------------------
 Changelog:
---------------------------------------------------------------
 Oct/25/2016 - 1.0
 * Initial version
-------------------------------------------------------------*/

function asb_api_activate() {
	if(wp_verify_nonce($_POST['asb_nonce_register'], 'asb_nonce_register')) {
		asb_api_response('register');
		asb_api_response('check');

		asb_return('analytics-spam-blocker', 400);
		exit;
	} else {
		asb_nonce_error();
		exit;
	}
}

function asb_api_deactivate() {
	asb_api_response('unregister', true);
}

function asb_api_blocklist_update() {
	asb_api_response('check');
}

function asb_report_submit() {
	if(wp_verify_nonce($_POST['asb_nonce_report'],'asb_nonce_report')) {
		$report['name'] = sanitize_text_field($_POST['asb_report_username']);
		$report['email'] = sanitize_email($_POST['asb_report_email']);
		$report['votes'] = esc_attr($_POST['asb_report_votes']);
		$report['domain'] = esc_url_raw(strtolower($_POST['asb_report_domain']));
		
		$report['domain'] = str_replace('http://', '', $report['domain']);
		$report['domain'] = str_replace('https://', '', $report['domain']);
		$report['domain'] = str_replace('//', '', $report['domain']);
		$report['domain'] = str_replace('/', '', $report['domain']); // Maybe not required
		$report['domain'] = str_replace('www.', '', $report['domain']); // Experiment?

		if(strlen($report['name']) < 1 OR strlen($report['email']) < 1 OR strlen($report['domain']) < 1) {
			asb_return('analytics-spam-blocker', 401);
		} else {
			asb_api_response('report', false, $report);
			asb_return('analytics-spam-blocker', 402);
			exit;
		}
	} else {
		adrotate_nonce_error();
		exit;
	}
}

function asb_api_response($request = '', $uninstall = false, $report = false) {

	$now = current_time('timestamp');
	$subscription = get_option('asb_subscription');
	$args = array('headers' => array('User-Agent' => 'Analytics Spam Blocker;' . get_option('siteurl')), 'sslverify' => false);

	$instance = ($request == 'register') ? 'reg' : $subscription['instance'];
	$auth = base64_encode($instance.':'.get_option('siteurl'));

	if($request == 'register') { 
		$do = '&do=reg';
	} else if($request == 'unregister') {
		$do = '&do=unreg';
	} else if($request == 'check') {
		$do = '&do=chk';
	} else if($request == 'report') {
		$report = base64_encode(serialize($report));
		$do = '&do=rep&report='.$report;
	} else { //Everything else
		$do = '';
	}
	
	$raw_response = wp_remote_get('https://ajdg.solutions/api/spam-blocker/1/?auth='.$auth.$do, $args);

	if($uninstall) return;
	
    if(!is_wp_error($raw_response)) {	
	    $response = json_decode($raw_response['body'], true);
		$result['status'] = $response['status'];
		
	    if($result['status'] == "reg") { // Registration
			$result['instance'] = (isset($response['instance'])) ? $response['instance'] : '';
			$result['registered'] = $now;

			update_option('asb_subscription', $result);
			update_option('asb_error', false);

			asb_schedule_updates();
			unset($response, $result);

			asb_return('analytics-spam-blocker', 200);
			exit;
	    } else if($result['status'] == "chk") { // Fetched new domains
			$current = get_option('asb_domains');
			$result['updated'] = (isset($response['updated'])) ? $response['updated'] : 0;
			$result['domains'] = (isset($response['domains'])) ? $response['domains'] : $current['domains'];

			// Maybe update htaccess
			if($result['updated'] > $current['updated']) asb_edit_htaccess($result['domains']);

			update_option('asb_domains', $result);
			update_option('asb_error', false);
			unset($response, $current, $result);
	    } else if($result['status'] == "rep") { // Reported domain
			$reports = get_option('asb_reports');
			if(isset($response['id'])) $reports[] = $response['id'];

			update_option('asb_reports', $reports);
			update_option('asb_error', false);
			unset($response, $reports);

			asb_return('analytics-spam-blocker', 201);
			exit;
		} else { // Everything else
			$result['error'] = $response['error'].' ('.date_i18n(get_option('date_format')." H:i", $now).')';

			update_option('asb_error', $result);
			unset($response, $result);
		}
	} else {
		$result['status'] = $raw_response->get_error_code();
		$result['error'] = $raw_response->get_error_message().' ('.date_i18n(get_option('date_format')." H:i", $now).')';
		update_option('asb_error', $result);
	}
}
?>